@@ -70,8 +70,8 @@ ario_notifier_libnotify_notify (ArioNotifier *notifier)
         gchar *secondary;
 
         switch (ario_server_get_current_state ()) {
-        case MPD_STATUS_STATE_PLAY:
-        case MPD_STATUS_STATE_PAUSE:
+        case ARIO_STATE_PLAY:
+        case ARIO_STATE_PAUSE:
                 /* Title */
                 title = ario_util_format_title (ario_server_get_current_song ());
                 ario_notifier_libnotify_set_string_property (notifier_libnotify, "summary", title);
@@ -80,10 +80,10 @@ ario_notifier_libnotify_notify (ArioNotifier *notifier)
                 artist = ario_server_get_current_artist ();
                 album = ario_server_get_current_album ();
 
-                if (!album)
-                        album = ARIO_SERVER_UNKNOWN;
                 if (!artist)
                         artist = ARIO_SERVER_UNKNOWN;
+                if (!album)
+                        album = ARIO_SERVER_UNKNOWN;
 
                 secondary = TRAY_ICON_FROM_MARKUP (album, artist);
                 ario_notifier_libnotify_set_string_property (notifier_libnotify, "body", secondary);
@@ -123,11 +123,8 @@ ario_notifier_libnotify_init (ArioNotifierLibnotify *notifier_libnotify)
         notifier_libnotify->priv = ARIO_NOTIFIER_LIBNOTIFY_GET_PRIVATE (notifier_libnotify);
 
         notifier_libnotify->priv->notification = notify_notification_new ("Ario",  NULL, NULL, NULL);
-#ifdef ENABLE_EGGTRAYICON
-        notify_notification_attach_to_widget (notifier_libnotify->priv->notification, GTK_WIDGET (ario_tray_icon_get_instance ()));
-#else
-        notify_notification_attach_to_status_icon (notifier_libnotify->priv->notification, GTK_STATUS_ICON (ario_tray_icon_get_instance ()));
-#endif
+        notify_notification_attach_to_status_icon (notifier_libnotify->priv->notification,
+                                                   GTK_STATUS_ICON (ario_tray_icon_get_instance ()));
 }
 
 static void
