@@ -225,6 +225,9 @@ ario_util_init_stock_icons (void)
         ario_util_add_stock_icons ("ario-pause", PIXMAP_PATH "ario-pause.png");
         ario_util_add_stock_icons ("repeat", PIXMAP_PATH "repeat.png");
         ario_util_add_stock_icons ("random", PIXMAP_PATH "shuffle.png");
+        ario_util_add_stock_icons ("pl-below", PIXMAP_PATH "pl-below.png");
+        ario_util_add_stock_icons ("pl-right", PIXMAP_PATH "pl-right.png");
+        ario_util_add_stock_icons ("pl-inside", PIXMAP_PATH "pl-inside.png");
 
         gtk_icon_factory_add_default (factory);
 }
@@ -694,13 +697,21 @@ ario_util_sanitize_filename (char *filename)
 {
         ARIO_LOG_FUNCTION_START;
         const char *to_strip = "#/*\"\\[]:;|=";
-        char *tmp;
+        static unsigned char translate[256];
+        static gboolean initialized = FALSE;
+        int c;
+        unsigned char *tmp;
+
+        if (!initialized) {
+                for (c = 0; c < 256; c++)
+                        translate[c] = strchr (to_strip, c)?
+                                               ' ': (unsigned char) c;
+                initialized = TRUE;
+        }
 
         /* We replace some special characters with spaces. */
-        for (tmp = filename; *tmp != '\0'; ++tmp) {
-                if (strchr (to_strip, *tmp))
-                        *tmp = ' ';
-        }
+        for (tmp = (unsigned char *) filename; *tmp != '\0'; ++tmp)
+                *tmp = translate[*tmp];
 }
 
 gboolean
@@ -830,3 +841,29 @@ ario_util_gslist_randomize (GSList **list,
 
         return ret;
 }
+
+gchar *
+ario_util_format_for_http (const gchar *text)
+{
+        int i;
+        int length;
+        gchar *res;
+
+        /* Normalize */
+        res = g_utf8_normalize (text, -1, G_NORMALIZE_ALL);
+
+        /* We escape special characters */
+        length = g_utf8_strlen (res, -1);
+        for(i = 0; i < length; ++i)
+        {
+                if (!g_unichar_isalnum (res[i])) {
+                        res[i]=' ';
+                }
+        }
+
+        /* We escape spaces */
+        ario_util_string_replace (&res, " ", "%20");
+
+        return res;
+}
+
