@@ -31,7 +31,7 @@
 #include "preferences/ario-others-preferences.h"
 #include "preferences/ario-playlist-preferences.h"
 #include "preferences/ario-server-preferences.h"
-#include "preferences/ario-trayicon-preferences.h"
+#include "preferences/ario-taskbar-preferences.h"
 #include "preferences/ario-stats-preferences.h"
 #include "ario-debug.h"
 
@@ -133,7 +133,7 @@ ario_shell_preferences_new (void)
                                   widget,
                                   gtk_label_new (_("Lyrics")));
 
-        widget = ario_trayicon_preferences_new ();
+        widget = ario_taskbar_preferences_new ();
         gtk_notebook_append_page (GTK_NOTEBOOK (shell_preferences->priv->notebook),
                                   widget,
                                   gtk_label_new (_("Notification")));
