@@ -136,7 +136,7 @@ static GtkActionEntry ario_playlist_actions [] =
         { "PlaylistShuffle", GTK_STOCK_REFRESH, N_("_Shuffle"), NULL,
                 NULL,
                 G_CALLBACK (ario_playlist_cmd_shuffle) },
-        { "PlaylistCrop", GTK_STOCK_CUT, N_("Cr_op"), NULL,
+        { "PlaylistCrop", GTK_STOCK_CUT, N_("Cr_op"), "<control>P",
                 NULL,
                 G_CALLBACK (ario_playlist_cmd_crop) },
         { "PlaylistSearch", GTK_STOCK_FIND, N_("_Search in playlist"), NULL,
@@ -258,19 +258,43 @@ static const GtkTargetEntry internal_targets  [] = {
 };
 
 #define ARIO_PLAYLIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ARIO_PLAYLIST, ArioPlaylistPrivate))
-G_DEFINE_TYPE (ArioPlaylist, ario_playlist, GTK_TYPE_VBOX)
+G_DEFINE_TYPE (ArioPlaylist, ario_playlist, ARIO_TYPE_SOURCE)
+
+static gchar *
+ario_playlist_get_id (ArioSource *source)
+{
+        return "playlist";
+}
+
+static gchar *
+ario_playlist_get_name (ArioSource *source)
+{
+        return _("Playlist");
+}
+
+static gchar *
+ario_playlist_get_icon (ArioSource *source)
+{
+        return GTK_STOCK_INDEX;
+}
 
 static void
 ario_playlist_class_init (ArioPlaylistClass *klass)
 {
         ARIO_LOG_FUNCTION_START;
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
+        ArioSourceClass *source_class = ARIO_SOURCE_CLASS (klass);
 
         /* Virtual methods */
         object_class->finalize = ario_playlist_finalize;
         object_class->set_property = ario_playlist_set_property;
         object_class->get_property = ario_playlist_get_property;
 
+        /* Virtual ArioSource methods */
+        source_class->get_id = ario_playlist_get_id;
+        source_class->get_name = ario_playlist_get_name;
+        source_class->get_icon = ario_playlist_get_icon;
+
         /* Properties */
         g_object_class_install_property (object_class,
                                          PROP_UI_MANAGER,
@@ -415,32 +439,35 @@ ario_playlist_filter_func (GtkTreeModel *model,
                             -1);
 
         /* Loop on every filter */
-        for (i = 0; cmp_str[i] && g_utf8_collate (cmp_str[i], "") && visible; ++i) {
-                /* By default the row doesn't match the filter */
-                filter = FALSE;
+        for (i = 0; cmp_str[i] && visible; ++i) {
+                if (g_utf8_collate (cmp_str[i], ""))
+                {
+                        /* By default the row doesn't match the filter */
+                        filter = FALSE;
 
-                /* The row match the filter if one of the visible column contains
-                 * the filter */
-                if (title
-                    && ario_conf_get_boolean (PREF_TITLE_COLUMN_VISIBLE, PREF_TITLE_COLUMN_VISIBLE_DEFAULT)
-                    && ario_util_stristr (title, cmp_str[i])) {
-                        filter = TRUE;
-                } else if (artist
-                           && ario_conf_get_boolean (PREF_ARTIST_COLUMN_VISIBLE, PREF_ARTIST_COLUMN_VISIBLE_DEFAULT)
-                           && ario_util_stristr (artist, cmp_str[i])) {
-                        filter = TRUE;
-                } else if (album
-                           && ario_conf_get_boolean (PREF_ALBUM_COLUMN_VISIBLE, PREF_ALBUM_COLUMN_VISIBLE_DEFAULT)
-                           && ario_util_stristr (album, cmp_str[i])) {
-                        filter = TRUE;
-                } else if (genre
-                           && ario_conf_get_boolean (PREF_GENRE_COLUMN_VISIBLE, PREF_GENRE_COLUMN_VISIBLE_DEFAULT)
-                           && ario_util_stristr (genre, cmp_str[i])) {
-                        filter = TRUE;
+                        /* The row match the filter if one of the visible column contains
+                         * the filter */
+                        if (title
+                            && ario_conf_get_boolean (PREF_TITLE_COLUMN_VISIBLE, PREF_TITLE_COLUMN_VISIBLE_DEFAULT)
+                            && ario_util_stristr (title, cmp_str[i])) {
+                                filter = TRUE;
+                        } else if (artist
+                                   && ario_conf_get_boolean (PREF_ARTIST_COLUMN_VISIBLE, PREF_ARTIST_COLUMN_VISIBLE_DEFAULT)
+                                   && ario_util_stristr (artist, cmp_str[i])) {
+                                filter = TRUE;
+                        } else if (album
+                                   && ario_conf_get_boolean (PREF_ALBUM_COLUMN_VISIBLE, PREF_ALBUM_COLUMN_VISIBLE_DEFAULT)
+                                   && ario_util_stristr (album, cmp_str[i])) {
+                                filter = TRUE;
+                        } else if (genre
+                                   && ario_conf_get_boolean (PREF_GENRE_COLUMN_VISIBLE, PREF_GENRE_COLUMN_VISIBLE_DEFAULT)
+                                   && ario_util_stristr (genre, cmp_str[i])) {
+                                filter = TRUE;
+                        }
+
+                        /* The row must match all the filters to be shown */
+                        visible &= filter;
                 }
-
-                /* The row must match all the filters to be shown */
-                visible &= filter;
         }
 
         g_strfreev (cmp_str);
@@ -512,7 +539,7 @@ ario_playlist_init (ArioPlaylist *playlist)
         ARIO_LOG_FUNCTION_START;
         int i;
         const gchar *column_names []  = { " ", _("Track"), _("Title"), _("Artist"), _("Album"), _("Duration"), _("File"), _("Genre"), _("Date"), _("Disc") };
-        GtkWidget *image, *close_button;
+        GtkWidget *image, *close_button, *vbox;
         GtkScrolledWindow *scrolled_window;
 
         /* Attributes initialization */
@@ -523,6 +550,9 @@ ario_playlist_init (ArioPlaylist *playlist)
         playlist->priv->playlist_length = 0;
         playlist->priv->play_pixbuf = gdk_pixbuf_new_from_file (PIXMAP_PATH "play.png", NULL);
 
+        /* Create main vbox */
+        vbox = gtk_vbox_new (FALSE, 0);
+
         /* Create scrolled window */
         scrolled_window = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (NULL, NULL));
         gtk_scrolled_window_set_policy (scrolled_window, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -653,17 +683,19 @@ ario_playlist_init (ArioPlaylist *playlist)
         gtk_widget_set_no_show_all (playlist->priv->search_hbox, TRUE);
         gtk_widget_hide (playlist->priv->search_hbox);
 
-        gtk_box_set_homogeneous (GTK_BOX (playlist), FALSE);
-
         /* Add scrolled window to playlist */
-        gtk_box_pack_start (GTK_BOX (playlist),
+        gtk_box_pack_start (GTK_BOX (vbox),
                             GTK_WIDGET (scrolled_window),
                             TRUE, TRUE, 0);
 
         /* Add search box to playlist */
-        gtk_box_pack_start (GTK_BOX (playlist),
+        gtk_box_pack_start (GTK_BOX (vbox),
                             playlist->priv->search_hbox,
                             FALSE, FALSE, 0);
+
+        gtk_box_pack_start (GTK_BOX (playlist),
+                            vbox,
+                            TRUE, TRUE, 0);
 }
 
 void
@@ -930,7 +962,17 @@ ario_playlist_state_changed_cb (ArioServer *server,
                                 ArioPlaylist *playlist)
 {
         ARIO_LOG_FUNCTION_START;
+        static gboolean first_run = TRUE;
+
+        /* Synchronise song information */
         ario_playlist_sync_song ();
+
+        /* Set focus to playlist at first start */
+        if (first_run
+            && ario_server_is_connected()) {
+                gtk_widget_grab_focus (playlist->priv->tree);
+                first_run = FALSE;
+        }
 }
 
 static void
